@@ -2,12 +2,11 @@
 #' @description 
 #' Simple approximation of the anisotropic diurnal heat (Ha) distribution 
 #'
-#' @param x          An elevation raster of class RasterLayer, SpatRaster or 
-#'                   SpatialPixelsDataFrame 
+#' @param x          An elevation raster of class terra SpatRaster
 #' @param amax       The Alpha Max (amax) parameter in degrees defined 
 #'                   as: minimum = 0, maximum = 360 with the default = 202.500  
 #'
-#' @return RasterLayer class object Diurnal Anisotropic Heat Index
+#' @return terra SpatRaster class object Diurnal Anisotropic Heat Index
 #'
 #' @description
 #' The Diurnal Anisotropic Heat Index is based on this equation.  
@@ -24,22 +23,15 @@
 #' @author Jeffrey S. Evans  <jeffrey_evans@@tnc.org> 
 #'
 #' @examples
-#' library(raster)
-#' data(elev)
+#' library(terra)
+#' elev <- rast(system.file("extdata/elev.tif", package="spatialEco"))
 #' Ha <- dahi(elev)
 #'   plot(Ha)
 #'
 #' @export dahi
 dahi <- function(x, amax = 202.500) {
-  if(class(x) == "RasterLayer") {
-    tr <- raster::terrain(x, opt=c("slope", "aspect"), 
-                          unit="degrees")				  
-  } else if(class(x) == "SpatRaster") {
-    tr <- raster::terrain(raster::raster(x), opt=c("slope", "aspect"), 
-                          unit="degrees")
-  } else if(class(x) == "SpatialPixelsDataFrame") {
-    tr <- raster::terrain(raster::raster(x), opt=c("slope", "aspect"), 
-                          unit="degrees")
-  }
+  if(!inherits(x, "SpatRaster"))
+    stop(deparse(substitute(x)), " must be a terra SpatRaster object")
+    tr <- terra::terrain(x, v=c("slope", "aspect"), unit="degrees")
   return( cos(amax - tr[[2]]) * atan(tr[[1]]) )
 }
