@@ -2,11 +2,11 @@
 #' @description Calculates the Evans (1972) Martonne's modified 
 #'              dissection 
 #' 
-#' @param x    raster object
+#' @param x    A terra SpatRaster class object
 #' @param s    Focal window size
-#' @param ...  Additional arguments passed to raster::calc
+#' @param ...  Additional arguments passed to terra::lapp
 #' 
-#' @return raster class object of Martonne's modified dissection  
+#' @return A SpatRaster class object of Martonne's modified dissection  
 #'
 #' @note
 #' Dissection is calculated as: 
@@ -16,19 +16,20 @@
 #' 
 #' @examples
 #' \donttest{ 
-#'   library(raster)
-#'   data(elev)
+#' library(terra)
+#' elev <- rast(system.file("extdata/elev.tif", package="spatialEco"))
 #'   d <- dissection(elev, s=3)
 #'     plot(d, main="dissection") 
 #' }     
 #'
 #' @export dissection
 dissection <- function(x, s=5, ...) {  
-  if (!inherits(x, "RasterLayer")) stop("MUST BE RasterLayer OBJECT")
+  if (!inherits(x, "SpatRaster")) 
+    stop(deparse(substitute(x)), " must be a terra SpatRaster object")		
     if( length(s) == 1) s = c(s[1],s[1])
        m <- matrix(1, nrow=s, ncol=s)
-    rmin <- raster::focal(x, w=m, fun=min)
-    rmax <- raster::focal(x, w=m, fun=max)
-    return( raster::calc(raster::stack(x,rmin,rmax), fun = function(x) { (x[1] - x[2] ) / 
-	        ( x[3] - x[2] ) }, ... )   )
+    rmin <- terra::focal(x, w=m, fun=min)
+    rmax <- terra::focal(x, w=m, fun=max)
+    return( terra::lapp(c(x,rmin,rmax), fun = function(x,y,z) { (x - y ) / 
+	        ( z - y ) }, ... )   )
 }  
